Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WriteConfigFile ¶
WriteConfigFile renders config using the template and writes it to configFilePath.
Types ¶
type Config ¶
type Config struct {
IsValidator bool
EthPrivKeyFile string
EthRootchain string
EthNodeURL string
EthMinFees string
EthBlockFinality string
}
Defines basic configuration needed to interact with a rootchain contract
func DefaultConfig ¶
func DefaultConfig() *Config
func ParseConfig ¶
parses the plasma.toml file and unmarshals it into a Config struct
Click to show internal directories.
Click to hide internal directories.